"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const node_1 = require("browserslist/node");
const mooli_scripts_1 = require("mooli-scripts");
const Entry_1 = require("./plugins/Entry");
const entry_1 = require("./libraries/entry");
const output_1 = require("./libraries/output");
const devtool_1 = require("./libraries/devtool");
const mode_1 = require("./libraries/mode");
const stats_1 = require("./libraries/stats");
const resolve_1 = require("./libraries/resolve");
const template_1 = require("./libraries/template");
const optimization_1 = require("./libraries/optimization");
const devserver_1 = require("./libraries/devserver");
const webpackMooli = (port = 3000, fn) => {
    return (env) => {
        const mooli = new mooli_scripts_1.moolipack(env.production ? 'production' : 'development', port);
        const excludeReg = /node_modules\/(?!(mooli-docs))/;
        // 基础配置
        mooli
            .target(node_1.findConfig(process.cwd()) ? 'browserlists' : 'web')
            .entry(entry_1.getEntry())
            .output(output_1.setOutput)
            .devtool(devtool_1.setDevtool)
            .mode(mode_1.setMode)
            .stats(stats_1.setStats)
            .optimization(optimization_1.setOptimization)
            .resolve(resolve_1.setResolve)
            .devServer(devserver_1.setDevServer)
            .miniCss(mooli.isBuild());
        // 插件
        mooli
            .pluginClean((plugin) => {
            plugin.enable(mooli.isBuild());
        })
            .pluginErrorOverlay((plugin) => {
            plugin.enable(mooli.isHot());
        })
            .addPlugin(new Entry_1.EntryPlugin())
            .pluginHtml(template_1.getHtmlTemplate())
            .pluginHotModuleReplace((plugin) => {
            plugin.enable(mooli.isHot());
        })
            .pluginReactRefresh((plugin) => {
            plugin.enable(mooli.isHot());
        })
            .pluginProgressBar((plugin) => {
            plugin.enable(mooli.isBuild());
        });
        // 规则
        mooli
            .ruleTsx((rule) => {
            rule.setExclude(excludeReg);
            rule.enable(mooli.hasPackage('typescript'));
        })
            .ruleJsx((rule) => {
            rule.setExclude(excludeReg);
        })
            .ruleCss((rule) => {
            rule.setExclude(excludeReg);
        })
            .ruleCssNodeModules((rule) => {
            rule.setExclude(excludeReg);
        })
            .ruleScss((rule) => {
            rule.setExclude(excludeReg);
        })
            .ruleLess((rule) => {
            rule.setExclude(excludeReg);
        })
            .ruleAsset((rule) => {
            rule.setExclude(excludeReg);
        })
            .ruleHtml((rule) => {
            rule.setExclude(excludeReg);
        })
            .ruleRaw((rule) => {
            rule.setExclude(excludeReg);
        })
            .ruleJson5((rule) => {
            rule.setExclude(excludeReg);
        });
        // 自定义配置
        fn === null || fn === void 0 ? void 0 : fn(mooli);
        // 优化
        mooli.optimization(optimization_1.setOptimizationAfter.bind(global, mooli.getUglifyConfig()));
        // 启动服务
        mooli.devServer(devserver_1.setDevServerAfter);
        return mooli.collect();
    };
};
exports.default = webpackMooli;
