"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EntryPlugin = void 0;
const fast_glob_1 = __importDefault(require("fast-glob"));
const path_1 = require("path");
const fs_extra_1 = require("fs-extra");
const paths_1 = require("../utils/paths");
const utils_1 = require("../utils/utils");
const PLUGIN_NAME = 'MooliEntryPlugin';
const resolveDocuments = (components) => {
    const mooliConfig = utils_1.getMooliConfig();
    const { locales, defaultLang } = mooliConfig.site;
    const docs = [];
    const dirName = (paths_1.COMPONENTS_DIR.split(path_1.sep) || []).pop();
    if (locales) {
        const langs = Object.keys(locales);
        langs.forEach((lang) => {
            const fileName = `index.${lang}.md`;
            components.forEach((component) => {
                const componentPath = path_1.join(paths_1.COMPONENTS_DIR, component, fileName);
                if (fs_extra_1.existsSync(componentPath)) {
                    docs.push({
                        name: dirName + '_' + utils_1.formatName(component, lang),
                        path: componentPath,
                    });
                }
            });
        });
    }
    else {
        components.forEach((component) => {
            const componentPath = path_1.join(paths_1.COMPONENTS_DIR, component, 'index.md');
            if (fs_extra_1.existsSync(componentPath)) {
                docs.push({
                    name: dirName + '_' + utils_1.formatName(component),
                    path: componentPath,
                });
            }
        });
    }
    const staticDocs = fast_glob_1.default
        .sync(utils_1.normalizePath(path_1.join(paths_1.DOCS_DIR, '**/*.md')))
        .map((path) => {
        const pairs = path_1.parse(path).name.split('.');
        const dirName = (paths_1.DOCS_DIR.split(path_1.sep) || []).pop();
        return {
            name: dirName + '_' + utils_1.formatName(pairs[0], pairs[1] || defaultLang),
            path,
        };
    });
    return [...staticDocs, ...docs];
};
const entryStyle = () => {
    let content = '';
    const cssType = ['.css', '.less', '.scss'];
    const components = fs_extra_1.readdirSync(paths_1.COMPONENTS_DIR);
    components.forEach((component) => {
        if (/\.[^.]+/.exec(component))
            return;
        const path = path_1.join(paths_1.COMPONENTS_DIR, `${component}/style/`);
        if (fs_extra_1.existsSync(path)) {
            const fileArr = fs_extra_1.readdirSync(path);
            if (fileArr && fileArr.length > 0) {
                fileArr.forEach(file => {
                    const extName = path_1.extname(file);
                    if (cssType.includes(extName)) {
                        const filepath = path_1.join(path, file);
                        content += `@import "${utils_1.normalizePath(filepath)}";\n`;
                    }
                });
            }
        }
    });
    utils_1.smartOutputFile(paths_1.ENTRY_STYLE_FILE, content);
};
const entryJs = () => {
    const dirs = fs_extra_1.readdirSync(paths_1.COMPONENTS_DIR);
    const documents = resolveDocuments(dirs);
    const code = `${utils_1.genImportConfig()}
${utils_1.genExportConfig()}
${utils_1.genImportDocuments(documents)}
${utils_1.genExportDocuments(documents)}`;
    utils_1.smartOutputFile(paths_1.ENTRY_JS_FILE, code);
};
const genSiteEntry = () => {
    return new Promise((resolve) => {
        entryStyle();
        entryJs();
        resolve();
    });
};
class EntryPlugin {
    apply(compiler) {
        if (process.env.NODE_ENV === 'production') {
            compiler.hooks.beforeCompile.tapPromise(PLUGIN_NAME, genSiteEntry);
        }
        else {
            compiler.hooks.watchRun.tapPromise(PLUGIN_NAME, genSiteEntry);
        }
    }
}
exports.EntryPlugin = EntryPlugin;
