"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTSConfig = exports.getMooliConfig = exports.getEntry = exports.getFileName = exports.genExportDocuments = exports.genImportDocuments = exports.genExportConfig = exports.genImportConfig = exports.isTsFile = exports.isTransform = exports.replaceExt = exports.removeExt = exports.smartOutputFile = exports.normalizePath = exports.formatName = exports.pascalize = exports.camelize = void 0;
const path_1 = __importDefault(require("path"));
const lodash_1 = require("lodash");
const fs_extra_1 = require("fs-extra");
const paths_1 = require("./paths");
const camelize = (str) => {
    return str.replace(/-(\w)/g, (_, c) => c.toUpperCase());
};
exports.camelize = camelize;
const pascalize = (str) => {
    return exports.camelize(str).replace(/(\w)(\w*)/g, (_, c1, c2) => c1.toUpperCase() + c2);
};
exports.pascalize = pascalize;
const formatName = (component, lang) => {
    component = exports.pascalize(component);
    if (lang) {
        return `${component}_${lang.replace('-', '_')}`;
    }
    return component;
};
exports.formatName = formatName;
const normalizePath = (path) => {
    return path.replace(/\\/g, '/');
};
exports.normalizePath = normalizePath;
const smartOutputFile = (filePath, content) => {
    if (fs_extra_1.existsSync(filePath)) {
        const previousContent = fs_extra_1.readFileSync(filePath, 'utf-8');
        if (previousContent === content) {
            return;
        }
    }
    fs_extra_1.outputFileSync(filePath, content);
};
exports.smartOutputFile = smartOutputFile;
function removeExt(path) {
    return path.replace('.js', '');
}
exports.removeExt = removeExt;
function replaceExt(path, ext) {
    return path.replace(/\.\w+$/, ext);
}
exports.replaceExt = replaceExt;
const isTransform = (regexp, path) => {
    return regexp.test(path) && !path.endsWith(".d.ts");
};
exports.isTransform = isTransform;
const isTsFile = (path) => {
    return /\.tsx?$/.test(path) && !path.endsWith(".d.ts");
};
exports.isTsFile = isTsFile;
const genImportConfig = () => {
    return `import config from '${removeExt(exports.normalizePath(paths_1.MOOLI_CONFIG_FILE))}';`;
};
exports.genImportConfig = genImportConfig;
const genExportConfig = () => {
    return 'export { config };';
};
exports.genExportConfig = genExportConfig;
const genImportDocuments = (items) => {
    return items
        .map((item) => `import ${item.name} from '${exports.normalizePath(item.path)}';`)
        .join('\n');
};
exports.genImportDocuments = genImportDocuments;
const genExportDocuments = (items) => {
    return `export const documents = {
  ${items.map((item) => item.name).join(',\n  ')}
};`;
};
exports.genExportDocuments = genExportDocuments;
const getFileName = (filePath) => {
    return path_1.default.parse(filePath);
};
exports.getFileName = getFileName;
const getEntry = (entry) => {
    let newEntry = {};
    if (lodash_1.isString(entry)) {
        const { name } = exports.getFileName(entry);
        if (name)
            newEntry[name] = entry;
    }
    if (lodash_1.isObject(entry)) {
        Object.assign(newEntry, entry);
    }
    if (lodash_1.isArray(entry)) {
        entry.forEach(file => {
            const { name } = exports.getFileName(file);
            if (name)
                newEntry[name] = file;
        });
    }
    return newEntry;
};
exports.getEntry = getEntry;
function getMooliConfig(path = paths_1.MOOLI_CONFIG_FILE) {
    delete require.cache[path];
    try {
        return require(path);
    }
    catch (err) {
        return {};
    }
}
exports.getMooliConfig = getMooliConfig;
const getTSConfig = () => {
    const tsconfig = getMooliConfig(paths_1.TS_CONFIG__JSON_FILE);
    if (tsconfig && Object.keys(tsconfig).length > 0) {
        return tsconfig.compilerOptions;
    }
    return {
        "allowSyntheticDefaultImports": true,
        "declaration": true,
        "module": "esnext",
        "target": "esnext",
        "moduleResolution": "node",
        "jsx": "react",
        "skipLibCheck": true
    };
};
exports.getTSConfig = getTSConfig;
