import { documents, config } from 'entry-js';

const { routeClassify = false } = config.site;

const componentDir = config.paths && config.paths.componentDir || 'components'

function decamelize(str, sep = '-') {
  return str
    .replace(/([\da-z])([A-Z])/g, `$1${sep}$2`)
    .replace(/([A-Z]+)([A-Z][\da-z]+)/g, `$1${sep}$2`)
    .toLowerCase();
}

function parseName(name) {
  if (name.indexOf('_') !== -1) {
    const pairs = name.split('_');
    const dirName = pairs.shift();
    const component = pairs.shift();
    return {
      dirname: dirName,
      component: `${decamelize(component)}`,
      lang: pairs.join('-'),
    };
  }
  return {
    dirname: '',
    component: `${decamelize(name)}`,
    lang: '',
  };
}

// 组件路由
function componentRoutes() {
  const routes = {};
  const names = Object.keys(documents);

  names.forEach((name) => {
    const { dirname, component, lang } = parseName(name);
    let lg = '';
    if (lang) lg = `/${lang}`

    let curDirname = dirname;

    // 路由不做分类(todo 这边将dirname和path都保持与组件一致，追求最大渲染速度)
    if (!routeClassify) curDirname = componentDir;
    if (!routes[curDirname]) routes[curDirname] = [];

    routes[curDirname].push({
      dirname: curDirname,
      name: component,
      path: `/${curDirname}/${component}${lg}`,
      component: documents[name]
    })
  });

  return routes;
}

export default componentRoutes();
