import React, { useEffect } from 'react';
import marked from 'marked';
import Prism from 'prismjs';
import 'prismjs/components/prism-bash';
import 'prismjs/components/prism-jsx';

import './prism.less'; // 默认样式
import './style.less';


function cardWrapper(html) {
  const group = html
    .replace(/<h3/g, ':::<h3')
    .replace(/<h2/g, ':::<h2')
    .split(':::');

  return group
    .map((fragment) => {
      if (fragment.indexOf('<h3') !== -1) {
        return `<div class="card">${fragment}</div>`;
      }

      return fragment;
    })
    .join('');
}

function formatName(name) {
  if (!name) return '';

  let str = name.split('\n\r')[0] || '';
  str = str.replace('# ', '');
  str = str.replace(' ', '');
  str = str.replace(/[\u4e00-\u9fa5]/g, '');
  str = str.toLowerCase();

  return str;
}

export default (props) => {
  const { content } = props;
  const getRenderer = () => {
    const renderer = new marked.Renderer();

    // 代码
    renderer.code = (code, language) => {
      const highlightCode =
        Object.keys(Prism.languages).indexOf(language) > -1
          ? Prism.highlight(code, Prism.languages[language], language)
          : code;
      return `<pre class="language-${language}"><code class="language-${language}">${highlightCode}</code></pre>`;
    };

    return renderer;
  };

  useEffect(() => {
    window.scrollTo(0, 0);
  }, []);

  if (typeof content === 'string') {
    const demoHTML = marked(content.replace(/## API\s?([^]+)/g, ''), {
      renderer: getRenderer(),
    });
    const api = content.match(/## API\s?([^]+)/g);
    const apiHTML = marked(
      Object.prototype.toString.call(api) === '[object Array]' ? api[0] : '',
      {
        renderer: getRenderer(),
      },
    );
    const demoTitle = formatName(content);

    return (
      <>
        <div className="md-container">
          <div
            className={`md-demo md-${demoTitle}`}
            dangerouslySetInnerHTML={{ __html: cardWrapper(demoHTML) }}
          />
          <div
            className="md-api"
            dangerouslySetInnerHTML={{ __html: cardWrapper(apiHTML) }}
          />
        </div>
      </>
    );
  }

  return <span />;
};
