import React from 'react';
import classnames from 'classnames';
import { Route, Switch, useParams } from 'react-router-dom';
import Header from '../components/Header';
import Container from '../components/Container';
import Simulator from '../components/Simulator';
import SideBar from '../components/SideBar';
import Markdown from '../components/Markdown';
import { getLang, setDefaultLang } from '../../common/locale';
import { config } from 'entry-js';

const { defaultLang } = config.site;

setDefaultLang(defaultLang);

const getSimulator = (nav, component, className) => {
  let curHideSimulator = false;
  nav.forEach((val) => {
    val.items.forEach((item) => {
      if (item.path === component) {
        if (item.hasOwnProperty(className)) {
          curHideSimulator = item[className];
        } else if (val.hasOwnProperty(className)) {
          curHideSimulator = val[className];
        }
      }
    });
  });
  return curHideSimulator;
};

const LoadableComponent = (content) => <Markdown content={content} />;

const Layout = (props) => {
  const { locales, hideInSimulator, hideInSide, title, logo } = config.site;
  const lang = getLang();
  const locale = locales[lang];

  const params = useParams();
  const { component = '' } = params;
  const { nav } = locale;

  const curHideSimulator =
    hideInSimulator || getSimulator(nav, component, 'hideInSimulator');
  const curHideSide = hideInSide || getSimulator(nav, component, 'hideInSide');

  const className2Use = classnames('mooli-doc', {
    hideSimulator: curHideSimulator,
    hideSide: curHideSide,
  });

  return (
    <div className={className2Use}>
      <Header locale={locale} lang={lang} title={title} logo={logo} />
      <SideBar locale={locale} lang={lang} />
      <Container>
        <Switch>
          {props.route.children.map((route, i) => (
            <Route
              key={Number(i)}
              path={route.path}
              component={() => LoadableComponent(route.component)}
            />
          ))}
        </Switch>
        <Simulator hideSimulator={curHideSimulator} lang={lang} />
      </Container>
    </div>
  );
};

export default Layout;
