import React, { useEffect, useRef, useCallback } from 'react';
import ReactDOM from 'react-dom';
import { transform } from 'babel-standalone';

export default ({ globalContext, children }) => {
  const containerId = parseInt((Math.random() * 1e9), 10).toString(36);
  const document = children.match(/([^]*)\n?(```[^]+```)/);
  if (!document) return null;

  const title = String(document?.[1].match(/(.*)\n?([^]+)/)[1]).replace(
    '### ',
    '',
  );

  const containerRef = useRef(null);

  const renderSource = useCallback(() => {
    import('mooli-mobile')
      .then((Element) => {
        const args = ['React', 'ReactDOM', 'Mooli'];
        const argv = [React, ReactDOM, Element];
        return {
          args,
          argv,
        };
      })
      .then(({ args, argv }) => {
        let value = '';
        if (document) {
          const source = document[2].match(/```(.*)\n?([^]+)```/);
          value = source[2]
            .replace(
              /import\s+{\s+(.*)\s+}\s+from\s+'react';/,
              'const { $1 } = React;',
            )
            .replace(
              /import\s+{\s+(.*)\s+}\s+from\s+'mooli-mobile';/,
              'const { $1 } = Mooli;',
            )
            // 替换格式
            .replace(
              /ReactDOM.render\(\s?([^]+?)(,\s?mountNode\s?\))/g,
              `ReactDOM.render($1, document.getElementById('${containerId}'))`,
            )
            .replace(
              /ReactDOM.render\(\s?([^]+?)(,([\n\r])(\s)*mountNode,\s?\))/g,
              `ReactDOM.render($1, document.getElementById('${containerId}'))`,
            )
            .replace('mountNode', `document.getElementById('${containerId}')`);
        }
        const { code } = transform(value, {
          presets: ['es2015', 'react'],
          plugins: ["transform-object-rest-spread","transform-object-assign"],
        });
        if (code) args.push(code);
        new Function(...args)(...argv);
      })
      .catch((err) => {
        console.log(err);
      });
  }, [containerId, document, globalContext]);

  useEffect(() => {
    renderSource();
    return () => {
      if (containerRef?.current) {
        ReactDOM.unmountComponentAtNode(containerRef.current);
      }
    };
  }, [renderSource]);

  return (
    <div className="simulator-block">
      <div className="simulator-block-title">{title}</div>
      <div
        className="simulator-block-body"
        id={containerId}
        ref={containerRef}
      />
    </div>
  );
};
