import React, { useEffect, useContext } from 'react';
import ReactDOM from 'react-dom';
import classnames from 'classnames';
import marked from 'marked';
import Context from '../../../common/context';
import Example from './Example';
import './style.less';

export default (props) => {
  const globalContext = useContext(Context);
  const { content, name } = props;
  const components = new Map();
  const nodeList = [];

  if (typeof content !== 'string') return null;
  const renderDOM = () => {
    for (const [id, component] of components) {
      const div = document.getElementById(id);
      if (div && div instanceof HTMLElement) {
        nodeList.push(div);
        ReactDOM.render(component, div);
      }
    }
  };

  useEffect(() => {
    renderDOM();
    return () => {
      nodeList.forEach((node) => {
        ReactDOM.unmountComponentAtNode(node);
      });
    };
  });

  const html = marked(
    content
      .replace(/## API\s?([^]+)/g, '') // 排除API显示
      .replace(/###\s?([^]+?)((?=###)|$)/g, (code) => {
        const id = parseInt((Math.random() * 1e9), 10).toString(36);
        components.set(
          id,
          React.createElement(Example, { ...props, globalContext }, code),
        );
        return `<div id=${id}></div>`;
      }),
    {
      renderer: new marked.Renderer(),
    },
  );

  const className = classnames('simulator-section', {
    [`simulator-section-${name}`]: name
  });

  return (
    <section
      className={className}
      dangerouslySetInnerHTML={{ __html: html }}
    />
  );
};
